@@ -59,7 +59,7 @@ class PatrowlHearsApi:
 
         try:
             r = requests.Request(method=method, url=self.url+url, data=data, headers={'Authorization': 'Token {}'.format(self.auth_token)})
-            pr = r.prepare_request()
+            pr = r.prepare()
             return self.rs.send(pr).json()
         except requests.exceptions.RequestException as e:
             raise PatrowlHearsException("Unable to retrieve vuln: {}".format(e))
